'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.watchViewportResize = watchViewportResize;
exports.unwatchViewportResize = unwatchViewportResize;
var isMonitoring = false;
var isResizing = false;
var watchers = new Set();

function getDocumentHeight() {
  return Math.max(document.body.scrollHeight, document.documentElement.scrollHeight, document.body.offsetHeight, document.documentElement.offsetHeight, document.body.clientHeight, document.documentElement.clientHeight);
}

function getDocumentWidth() {
  return Math.max(document.body.scrollWidth, document.documentElement.scrollWidth, document.body.offsetWidth, document.documentElement.offsetWidth, document.body.clientWidth, document.documentElement.clientWidth);
}

function onResize() {
  if (!isResizing) {
    isResizing = true;
    requestAnimationFrame(update);
  }
}

function update() {
  isResizing = false;
  var width = window.innerWidth;
  var height = window.innerHeight;
  watchers.forEach(function (cb) {
    return cb({
      width: width,
      height: height,
      scrollWidth: getDocumentWidth(),
      scrollHeight: getDocumentHeight()
    });
  });
}

function start() {
  if (!isMonitoring) {
    onResize();
    window.addEventListener('resize', onResize);
    isMonitoring = true;
  }
}

function stop() {
  if (isMonitoring) {
    watchers.clear();
    window.removeEventListener('resize', onResize);
    isMonitoring = false;
  }
}

function watchViewportResize(cb) {
  if (!isMonitoring) start();
  watchers.add(cb);
}

function unwatchViewportResize(cb) {
  watchers.delete(cb);
  if (!watchers.size) stop();
}