'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.watchViewportScroll = watchViewportScroll;
exports.unwatchViewportScroll = unwatchViewportScroll;
var isMonitoring = false;
var isScrolling = false;
var latestScrollX = 0;
var latestScrollY = 0;
var watchers = new Set();

function onScroll() {
  if (!isScrolling) {
    isScrolling = true;
    requestAnimationFrame(update);
  }
}

function update() {
  isScrolling = false;
  var scrollX = window.pageXOffset;
  var scrollY = window.pageYOffset;
  var scrollXDirection = scrollX - latestScrollX > 0 ? 'down' : 'up';
  var scrollYDirection = scrollY - latestScrollY > 0 ? 'down' : 'up';
  watchers.forEach(function (cb) {
    return cb({
      scrollX: scrollX,
      scrollY: scrollY,
      scrollXDirection: scrollXDirection,
      scrollYDirection: scrollYDirection
    });
  });
  latestScrollX = scrollX;
  latestScrollY = scrollY;
}

function start() {
  if (!isMonitoring) {
    window.addEventListener('scroll', onScroll);
    isMonitoring = true;
  }
}

function stop() {
  if (isMonitoring) {
    watchers.clear();
    window.removeEventListener('scroll', onScroll);
    isMonitoring = false;
  }
}

function watchViewportScroll(cb) {
  if (!isMonitoring) start();
  watchers.add(cb);
}

function unwatchViewportScroll(cb) {
  watchers.delete(cb);
  if (!watchers.size) stop();
}